@@ -5,6 +5,7 @@ import re
 import sys
 import os
 import pytest
+import copy
 import wcmatch.fnmatch as fnmatch
 from unittest import mock
 from wcmatch import util
@@ -776,3 +777,47 @@ class TestTypes(unittest.TestCase):
         """Test `list` matching."""
 
         self.assertTrue(fnmatch.fnmatch('a', ['a']))
+
+
+class TestPrecompile(unittest.TestCase):
+    """Test precompiled match objects."""
+
+    def test_precompiled_match(self):
+        """Test precompiled matching."""
+
+        m = fnmatch.compile('*file')
+        self.assertTrue(m.match('testfile'))
+
+    def test_precompiled_match_empty(self):
+        """Test precompiled matching with empty input."""
+
+        m = fnmatch.compile('*file')
+        self.assertFalse(m.match(''))
+
+    def test_precompiled_filter(self):
+        """Test precompiled filtering."""
+
+        m = fnmatch.compile('*file')
+        self.assertEqual(m.filter(['testfile', 'test_2_file', 'nope']), ['testfile', 'test_2_file'])
+
+    def test_precompiled_filter_empty(self):
+        """Test precompiled filtering with empty input."""
+
+        m = fnmatch.compile('*file')
+        self.assertEqual(m.filter([]), [])
+
+    def test_hash(self):
+        """Test hashing."""
+
+        m1 = fnmatch.compile('test', flags=fnmatch.C)
+        m2 = fnmatch.compile('test', flags=fnmatch.C)
+        m3 = fnmatch.compile('test', flags=fnmatch.I)
+        m4 = fnmatch.compile(b'test', flags=fnmatch.C)
+
+        self.assertTrue(m1 == m2)
+        self.assertTrue(m1 != m3)
+        self.assertTrue(m1 != m4)
+
+        m5 = copy.copy(m1)
+        self.assertTrue(m1 == m5)
+        self.assertTrue(m5 in {m1})
